==> kafka-streams-scala_2.12-5.4.6-ccs-test-sources.jar: org/apache/kafka/streams/scala/kstream/GroupedTest.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.kafka.streams.scala.kstream

import org.apache.kafka.streams.kstream.internals.GroupedInternal
import org.apache.kafka.streams.scala.Serdes
import org.apache.kafka.streams.scala.Serdes._
import org.junit.runner.RunWith
import org.scalatest.junit.JUnitRunner
import org.scalatest.{FlatSpec, Matchers}

@RunWith(classOf[JUnitRunner])
class GroupedTest extends FlatSpec with Matchers {

  "Create a Grouped" should "create a Grouped with Serdes" in {
    val grouped: Grouped[String, Long] = Grouped.`with`[String, Long]

    val internalGrouped = new GroupedInternal[String, Long](grouped)
    internalGrouped.keySerde.getClass shouldBe Serdes.String.getClass
    internalGrouped.valueSerde.getClass shouldBe Serdes.Long.getClass
  }

  "Create a Grouped with repartition topic name" should "create a Grouped with Serdes, and repartition topic name" in {
    val repartitionTopicName = "repartition-topic"
    val grouped: Grouped[String, Long] = Grouped.`with`(repartitionTopicName)

    val internalGrouped = new GroupedInternal[String, Long](grouped)
    internalGrouped.keySerde.getClass shouldBe Serdes.String.getClass
    internalGrouped.valueSerde.getClass shouldBe Serdes.Long.getClass
    internalGrouped.name() shouldBe repartitionTopicName
  }

}

==> kafka-streams-scala_2.12-6.0.15-ccs-test-sources.jar: org/apache/kafka/streams/scala/kstream/GroupedTest.scala <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package org.apache.kafka.streams.scala.kstream

import org.apache.kafka.streams.kstream.internals.GroupedInternal
import org.apache.kafka.streams.scala.Serdes
import org.apache.kafka.streams.scala.Serdes._
import org.junit.runner.RunWith
import org.scalatest.{FlatSpec, Matchers}
import org.scalatestplus.junit.JUnitRunner

@RunWith(classOf[JUnitRunner])
class GroupedTest extends FlatSpec with Matchers {

  "Create a Grouped" should "create a Grouped with Serdes" in {
    val grouped: Grouped[String, Long] = Grouped.`with`[String, Long]

    val internalGrouped = new GroupedInternal[String, Long](grouped)
    internalGrouped.keySerde.getClass shouldBe Serdes.String.getClass
    internalGrouped.valueSerde.getClass shouldBe Serdes.Long.getClass
  }

  "Create a Grouped with repartition topic name" should "create a Grouped with Serdes, and repartition topic name" in {
    val repartitionTopicName = "repartition-topic"
    val grouped: Grouped[String, Long] = Grouped.`with`(repartitionTopicName)

    val internalGrouped = new GroupedInternal[String, Long](grouped)
    internalGrouped.keySerde.getClass shouldBe Serdes.String.getClass
    internalGrouped.valueSerde.getClass shouldBe Serdes.Long.getClass
    internalGrouped.name() shouldBe repartitionTopicName
  }

}
